GamepadConnectionEvent class

Represents a gamepad controller being connected to or disconnected from the device.

Constructors

GamepadConnectionEvent({required String gamepadId, required String name, required GamepadConnectionEventType type})
GamepadConnectionEvent.parse(Map map)
factory

Properties

gamepadId String
The id of the gamepad controller that was connected or disconnected.
final
hashCode int
The hash code for this object.
no setterinherited
name String
A user-facing, platform-dependant name for the gamepad controller.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type GamepadConnectionEventType
Whether the gamepad was connected or disconnected.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited