gamepadId property
The id of the gamepad controller that was connected or disconnected.
It matches the id reported by listGamepads and the gamepadId of the
events fired by that controller.
Implementation
final String gamepadId;
The id of the gamepad controller that was connected or disconnected.
It matches the id reported by listGamepads and the gamepadId of the
events fired by that controller.
final String gamepadId;